# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Classes

* [`motd`](#motd): Setup the Message Of The Day on Windows and Linux.

## Classes

### motd

*Linux*
Management of the files at:
  * `/etc/motd`
  * `/etc/issue`
  * `/etc/issue.net`

*Windows*
On windows there is only one message which we write to registry key:
  `HKEY_LOCAL_MACHINE\Software\Microsoft\Windows\CurrentVersion\policies\system\legalnoticetext`

* **See also**
https://forge.puppet.com/puppetlabs/registry

#### Examples

##### Default message

```puppet
1f4ac00d071c (172.17.0.4)
===============================================================================
CentOS 7.4.1708 x86_64

Processor: 8 x Intel(R) Core(TM) i7-6820HQ CPU @ 2.70GHz
Kernel:    4.15.0-22-generic
Memory:    31.27 GiB
```

##### Use the generic MOTD from the template

```puppet
include motd
```

##### Setting MOTD for all files in one go

```puppet
class { "motd":
  content => "\n\nNOTICE:\n\nThis Server is Managed by Puppet and is a \
Cowboy free zone!\nBeware that changes maybe overwritten without notice.\
\n\nInstalled Modules: ",
  identical_content => true,
}
```

##### Hiera to set MOTD for all files in one go

```puppet
motd::identical_content: true
motd::content: |
  NOTICE:

  This Server is Managed by Puppet and is a Cowboy free zone!
  Beware that changes maybe overwritten without notice
```

##### Hiera to set Messages individually:

```puppet
motd::identical_content: true
motd::content: |
  NOTICE:

  This Server is Managed by Puppet and is a Cowboy free zone!
  Beware that changes maybe overwritten without notice
motd::issue_content: "Please login"
motd::issue_net_content: "Nothing to see here"
```

#### Parameters

The following parameters are available in the `motd` class.

##### `content`

Data type: `Variant[Boolean, Optional[String]]`

The message to use for login message (or all messages) on all platforms or `false` to write an empty
file

Default value: `undef`

##### `issue_content`

Data type: `Variant[Boolean, Optional[String]]`

The message  to be used for `/etc/issue` (pre-login message - linux only) or `false` to write an
empty file

Default value: `undef`

##### `issue_net_content`

Data type: `Variant[Boolean, Optional[String]]`

The message to be used for `/etc/issue.net` (pre-login message for telnet/other nominated
services - linux only) or `false` to write an empty file

Default value: `undef`

##### `identical_content`

Data type: `Boolean`

`true` to use the main MOTD message from `content` for all messages unless overriden
individually by `issue_content` and `issue_net` (linux only)

Default value: `false`

